import typer
from pathlib import Path
from zona import builder, server
from zona.layout import Layout, discover_layout

app = typer.Typer()


@app.command()
def build(root: Path | None = None, output: Path | None = None):
    layout: Layout = discover_layout(root, output)
    items = builder.discover(layout)
    builder.build(layout, items)


@app.command()
def serve(dir: Path = Path("public")):
    if not dir.exists():
        raise typer.BadParameter(f"Directory {dir} does not exist.")
    typer.echo(f"Serving files from {dir}")
    server.serve(dir)


@app.command()
def init():
    # init will populate the current directory with
    # the required folders and their default values
    print("Init logic here...")


def main():
    app()
