from pathlib import Path
from dataclasses import dataclass


@dataclass
class Layout:
    root: Path
    content: Path
    templates: Path
    output: Path

    @classmethod
    def from_input(cls, root: Path, output: Path | None = None) -> "Layout":
        layout = cls(
            root=root.resolve(),
            content=(root / "content").resolve(),
            templates=(root / "templates").resolve(),
            output=(root / "public").resolve() if not output else output,
        )
        for path in [layout.content, layout.templates]:
            if not path.is_dir():
                raise FileNotFoundError(f"Missing required directory: {path}")
        return layout


def discover_layout(
    cli_root: Path | None = None, cli_output: Path | None = None
) -> Layout:
    if cli_root:
        root = cli_root
    else:
        # TODO: config based discovery
        # We just set cwd for now
        root = Path(".")
    return Layout.from_input(root, cli_output)
